==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebForOfStateDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDescriptionMetadata } from "./WebBaseEventArgsDescriptionMetadata";
import { WebForOfStateDescription } from "./WebForOfStateDescription";
/**
 * @hidden
 */
export let WebForOfStateDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebForOfStateDescriptionMetadata extends Base {
        static b(a) {
            if (WebForOfStateDescriptionMetadata.a == null) {
                WebForOfStateDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebForOfStateDescriptionMetadata.c(WebForOfStateDescriptionMetadata.a);
            }
            if (a.j(WebForOfStateDescriptionMetadata.a)) {
                return;
            }
            a.y(WebForOfStateDescriptionMetadata.a);
        }
        static c(a) {
            WebBaseEventArgsDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:ForOfState");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
            a.item("StartIndex", "Number:double");
            a.item("ChunkSize", "Number:double");
        }
        static d(a) {
            WebForOfStateDescriptionMetadata.b(a);
            a.aa("WebForOfState", () => new WebForOfStateDescription());
            a.z("WebForOfState", WebForOfStateDescriptionMetadata.a);
        }
    }
    WebForOfStateDescriptionMetadata.$t = /*@__PURE__*/ markType(WebForOfStateDescriptionMetadata, 'WebForOfStateDescriptionMetadata');
    WebForOfStateDescriptionMetadata.a = null;
    return WebForOfStateDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebForOfStateDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDescriptionMetadata } from "./WebBaseEventArgsDescriptionMetadata";
import { WebForOfStateDescription } from "./WebForOfStateDescription";
/**
 * @hidden
 */
export let WebForOfStateDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebForOfStateDescriptionMetadata extends Base {
        static b(a) {
            if (WebForOfStateDescriptionMetadata.a == null) {
                WebForOfStateDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebForOfStateDescriptionMetadata.c(WebForOfStateDescriptionMetadata.a);
            }
            if (a.k(WebForOfStateDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebForOfStateDescriptionMetadata.a);
        }
        static c(a) {
            WebBaseEventArgsDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:ForOfState");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("StartIndex", "Number:double");
            a.item("ChunkSize", "Number:double");
        }
        static d(a) {
            WebForOfStateDescriptionMetadata.b(a);
            a.ac("WebForOfState", () => new WebForOfStateDescription());
            a.ab("WebForOfState", WebForOfStateDescriptionMetadata.a);
        }
    }
    WebForOfStateDescriptionMetadata.$t = /*@__PURE__*/ markType(WebForOfStateDescriptionMetadata, 'WebForOfStateDescriptionMetadata');
    WebForOfStateDescriptionMetadata.a = null;
    return WebForOfStateDescriptionMetadata;
})();
